<?php

if ( !function_exists( 'steaque_google_fonts_url' ) ) {
  /*
   * Register Google Font Family
   */
  function steaque_google_fonts_url() {
    $fonts_url = '';
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    $fjalla_one = _x( 'on', 'Fjalla One: on or off', 'steaque' );
    $poppins = _x( 'on', 'Poppins font: on or off', 'steaque' );
    $dancing_script = _x( 'on', 'Dancing Script: on or off', 'steaque' );

    if ( 'off' !== $fjalla_one || 'off' !== $poppins || 'off' !== $dancing_script ) {

      $font_families = array();

      if ( 'off' !== $fjalla_one ) {
        $font_families[] = 'Fjalla One';
      }

      if ( 'off' !== $dancing_script ) {
        $font_families[] = 'Dancing Script';
      }

      if ( 'off' !== $poppins ) {
        $font_families[] = 'Poppins:400,600,800';
      }

      $f_query_args = array(
        'family' => urlencode( implode( '|', $font_families ) ),
        'subset' => urlencode( 'latin-ext' ),
      );
      $fonts_url = add_query_arg( $f_query_args, '//fonts.googleapis.com/css' );

    }

    return esc_url_raw( $fonts_url );
  }

}

if ( !function_exists( 'steaque_enqueue_styles_and_scripts' ) ) {
  /**
   * This function enqueues the required css and js files.
   *
   * @return void
   */
  function steaque_enqueue_styles_and_scripts() {
    /**
     * Enqueue css files.
     */
    wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.min.css' );
    wp_enqueue_style( 'datepicker', get_template_directory_uri() . '/css/datepicker.min.css' );
    wp_enqueue_style( 'lineicons', get_template_directory_uri() . '/css/lineicons.css' );
    wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/css/fancybox.min.css' );
    wp_enqueue_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css' );
    wp_enqueue_style( 'odometer', get_template_directory_uri() . '/css/odometer.min.css' );
    wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
    wp_enqueue_style( 'steaque-main-style', get_template_directory_uri() . '/css/style.css' );
    wp_enqueue_style( 'steaque-stylesheet', get_stylesheet_uri() );
    wp_add_inline_style( 'steaque-stylesheet', steaque_dynamic_css() );

    /**
     * Enqueue javascript files.
     */

    wp_enqueue_script( 'comments', get_template_directory_uri() . '/js/comments.js', array(), false, false );
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/js/fancybox.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'odometer', get_template_directory_uri() . '/js/odometer.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/js/imagesloaded.pkgd.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'stellar', get_template_directory_uri() . '/js/jquery.stellar.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'datepicker', get_template_directory_uri() . '/js/datepicker.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'wow', get_template_directory_uri() . '/js/wow.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'swiper', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'steaque-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false, true );

    if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
      wp_enqueue_script( 'comment-reply' );
    }

    $data = array(
      'pre_loader_typewriter' => [],
      'audio_source' => '',
      'enable_sound_bar' => false
    );

    if ( steaque_get_option( 'enable_preloader' ) ) {
      $typewriter_text = [];
      $text_rotater = steaque_get_option( 'pre_loader_text_rotater' );
      if ( $text_rotater ) {
        foreach ( $text_rotater as $rotater ) {
          $typewriter_text[] = esc_html( $rotater[ 'title' ] );
        }
      }
      $data[ 'pre_loader_typewriter' ] = $typewriter_text;
    }


    $comment_data = array(
      'name' => esc_html__( 'Name is required', 'steaque' ),
      'email' => esc_html__( 'Email is required', 'steaque' ),
      'comment' => esc_html__( 'Comment is required', 'steaque' ),

    );

    wp_localize_script( 'steaque-scripts', 'data', $data );
    wp_localize_script( 'comments', 'comment_data', $comment_data );
  }

  add_action( 'wp_enqueue_scripts', 'steaque_enqueue_styles_and_scripts', 10 );
}

if ( !function_exists( 'steaque_dynamic_css' ) ) {
  function steaque_dynamic_css() {

    $styles = '';
    if ( steaque_get_option( 'logo_height' ) ) {
      $logo_height = str_replace( ' ', '', steaque_get_option( 'logo_height' ) );
      $logo_height = str_replace( 'px', '', $logo_height );
      $styles .= "
				.navbar .logo a img{
					height: {$logo_height}px;
				}
			";
    }
    if ( steaque_get_option( 'pageheader_height' ) ) {
      $pageheader_height = str_replace( ' ', '', steaque_get_option( 'pageheader_height' ) );
      $styles .= "
				.page-header{
					height: {$pageheader_height};
				}
			";
    }
    if ( steaque_get_option( 'enable_dynamic_color' ) ) {

      $site_color = ( steaque_get_option( 'theme_color' ) ) ? steaque_get_option( 'theme_color' ) : '#c58f59';
      $site_color2 = ( steaque_get_option( 'theme_color2' ) ) ? steaque_get_option( 'theme_color2' ) : '#f0e8d9';
      $body_bg_color = ( steaque_get_option( 'body_background_color' ) ) ? steaque_get_option( 'body_background_color' ) : '#131313';

      $styles .= "
	  
	  :root {
  --color-main: {$site_color} !important; 
  --color-dark: {$body_bg_color} !important;
  --color-light: {$site_color2} !important; 
}
	  
	  
				
			";
    }

    return $styles;
  }
}


add_action( 'init', 'steaque_dynamic_css' );
add_action(
  'after_setup_theme',
  function () {
    add_theme_support( 'html5', [ 'script', 'style' ] );
  }
);